Index: pkg/dartino/lib/dartino.dart |
diff --git a/pkg/fletch/lib/fletch.dart b/pkg/dartino/lib/dartino.dart |
similarity index 85% |
rename from pkg/fletch/lib/fletch.dart |
rename to pkg/dartino/lib/dartino.dart |
index 48b36cf6f299ec60220548fd39645845c952bc26..597d381f8dafec8523d82ce4b7d5fc54f2f8e21d 100644 |
--- a/pkg/fletch/lib/fletch.dart |
+++ b/pkg/dartino/lib/dartino.dart |
@@ -2,12 +2,12 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
/// Fletch utility package. |
/// |
/// This is a preliminary API. |
-library fletch; |
+library dartino; |
-import 'dart:fletch.ffi'; |
+import 'dart:dartino.ffi'; |
import 'package:ffi/ffi.dart'; |
final ForeignFunction _getVersion = ForeignLibrary.main.lookup('GetVersion'); |
@@ -2,12 +2,12 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-/// Fletch utility package. |
+/// Dartino utility package. |
/// |
/// This is a preliminary API. |